@@ -5,8 +5,8 @@
 ;; Author: Thanos Apollo <public@thanosapollo.org>
 ;; Keywords: extensions youtube videos
 ;; URL: https://thanosapollo.org/projects/yeetube/
-;; Package-Version: 2.1.10
-;; Package-Revision: e179f00b0651
+;; Package-Version: 2.1.11
+;; Package-Revision: 2eddda6d9305
 
 ;; Package-Requires: ((emacs "27.2") (compat "29.1.4.2"))
 
@@ -55,6 +55,16 @@
   :group 'external
   :prefix "yeetube-")
 
+(defcustom yeetube-torsocks-program (executable-find "torsocks")
+  "Path for torsocks executable."
+  :type 'string
+  :group 'yeetube)
+
+(defcustom yeetube-ytdlp-program (executable-find "yt-dlp")
+  "Path for yt-dlp executable."
+  :type 'string
+  :group 'yeetube)
+
 (defcustom yeetube-results-limit 20
   "Define a limit for search results."
   :type 'number
@@ -206,8 +216,7 @@ videos from.")
 (defun yeetube-get-url (&optional id type)
   "Get video or playlist url for entry ID, adjusted for TYPE."
   ;; When point is on thumbnail, id will be nil.
-  (let* ((id (or id (tabulated-list-get-id)
-		 (save-excursion (end-of-line) (tabulated-list-get-id))))
+  (let* ((id (or id (tabulated-list-get-id)))
 	 (entry (cadr (assoc id yeetube-content)))
 	 (type (or type (aref entry (- (length entry) 1)))))
     (format "%s%s" (if (eq type 'video)
@@ -219,8 +228,7 @@ videos from.")
 (defun yeetube-play ()
   "Play video at point in *yeetube* buffer."
   (interactive)
-  (let* ((id (or (tabulated-list-get-id) (save-excursion (end-of-line)
-							 (tabulated-list-get-id))))
+  (let* ((id (tabulated-list-get-id))
 	 (entry-content (cadr (assoc id yeetube-content)))
 	 (video-url (yeetube-get-url id))
 	 (video-title (aref entry-content (if yeetube-display-thumbnails-p 1 0)))
@@ -377,10 +385,10 @@ _ENVIRONMENT is the lexical environment."
 Image is inserted in BUFFER for ENTRY."
   (let ((url-buffer (current-buffer)))
     (unwind-protect
-        (if-let ((err (plist-get status :error)))
+        (if-let* ((err (plist-get status :error)))
             (message "Error %s in retrieving a thumbnail: %S" (car err) (cdr err))
-          (if-let ((handle (mm-dissect-buffer t))
-                   (image (mm-get-image handle)))
+          (if-let* ((handle (mm-dissect-buffer t))
+                    (image (mm-get-image handle)))
               (progn
                 (setf (image-property image :max-width) (car yeetube-thumbnail-size)
                       (image-property image :max-height) (cdr yeetube-thumbnail-size))
@@ -391,9 +399,8 @@ Image is inserted in BUFFER for ENTRY."
                     (save-excursion
                       (goto-char (point-min))
                       (search-forward (format "[[%s.jpg]]" (car entry)))
-                      ;; Ensure to remove the placeholder text
-                      (delete-region (match-beginning 0) (match-end 0))
-                      (insert-image image))))))
+                      (add-text-properties (match-beginning 0) (match-end 0)
+                                           `(display ,image)))))))
 	  (kill-buffer url-buffer)))))
 
 (defun yeetube--retrieve-thumbnail (url str buffer)
@@ -506,6 +513,8 @@ Image is inserted in BUFFER for ENTRY."
   "Get content from youtube."
   (setf yeetube-content nil)
   (goto-char (point-min))
+  (search-forward "ytInitialData")
+  (search-forward "\"contents\"")
   (let ((count 0)
         (result-rx
 	 (rx "\"" (or "video" (and (or "playlist" "compact") (? "Video"))) "Renderer\""))
@@ -570,9 +579,6 @@ Image is inserted in BUFFER for ENTRY."
 
 ;; Yeetube Download:
 
-(defvar yeetube-ytdlp (executable-find "yt-dlp")
-  "Path for yt-dlp executable.")
-
 ;;;###autoload
 (defun yeetube-download-change-directory ()
   "Change download directory."
@@ -594,16 +600,16 @@ Image is inserted in BUFFER for ENTRY."
 Optional values:
  NAME for custom file name.
  AUDIO-FORMAT to extract and keep contents as specified audio-format only."
-  (unless (executable-find "yt-dlp")
-    (error "Executable for yt-dlp not found.  Please install yt-dlp"))
-  (let* ((tor-command (when yeetube-enable-tor (executable-find "torsocks")))
+  (unless yeetube-ytdlp-program
+    (error "Executable for yt-dlp not found. Please set yeetube-ytdlp-program"))
+  (let* ((tor-command (when yeetube-enable-tor yeetube-torsocks-program))
          (name-command (when name (format "-o %s" (shell-quote-argument name))))
          (format-command (when audio-format
 			   (format "--extract-audio --audio-format %s"
 				   (shell-quote-argument audio-format))))
          (command (mapconcat 'identity (delq nil
 					     (list tor-command
-						   (executable-find "yt-dlp")
+						   yeetube-ytdlp-program
 						   (shell-quote-argument url)
 						   name-command format-command))
 			     " ")))
@@ -617,8 +623,6 @@ Content will be downloaded at `yeetube-download-directory'.
 Optionally, provide custom own URL."
   (interactive)
   (save-excursion
-    ;; When point is on thumbnail, id will be nil.
-    (and (null (tabulated-list-get-id)) (end-of-line))
     (let* ((id (tabulated-list-get-id))
 	   (entry-content (cadr (assoc id yeetube-content)))
 	   (type (aref entry-content (- (length entry-content) 1)))
